@@ -14,16 +14,17 @@
 # General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Germinate; see the file COPYING.  If not, write to the Free
-# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301, USA.
+# along with Germinate; see the file COPYING.  If not, see
+# <https://www.gnu.org/licenses/>.
 
+import base64
 import logging
 import os
 import shutil
+import subprocess
 import tempfile
 from contextlib import closing
-from urllib.parse import quote
+from urllib.parse import quote, urlparse
 from urllib.request import Request, urlopen
 
 import apt_pkg
@@ -110,7 +111,23 @@ class TagFile(Archive):
                 + ftppath
                 + suffix
             )
-            req = Request(url)
+            parsed = urlparse(url)
+            if parsed.username:
+                host_without_auth = parsed.hostname
+                if parsed.port:
+                    host_without_auth += ":" + str(parsed.port)
+                req = Request(
+                    parsed._replace(netloc=host_without_auth).geturl()
+                )
+                base64string = base64.b64encode(
+                    ("%s:%s" % (parsed.username, parsed.password)).encode()
+                )
+                req.add_header(
+                    "Authorization", "Basic %s" % base64string.decode()
+                )
+            else:
+                req = Request(url)
+
             filename = None
 
             if req.type != "file":
@@ -271,3 +288,48 @@ class TagFile(Archive):
         finally:
             if self._cleanup:
                 shutil.rmtree(dirname)
+
+
+class AptArchive(Archive):
+    def __init__(self, config_path):
+        self.config_path = config_path
+
+    def _get_files(self, identifier):
+        env = dict(os.environ, APT_CONFIG=self.config_path)
+        cmd = [
+            "apt-get",
+            "indextargets",
+            "--format",
+            "$(FILENAME)",
+            "Identifier: " + identifier,
+        ]
+        cp = subprocess.run(
+            cmd,
+            env=env,
+            capture_output=True,
+            encoding="utf-8",
+            check=True,
+        )
+        return cp.stdout.splitlines()
+
+    def sections(self):
+        for filename in self._get_files("Packages"):
+            _progress(
+                "processing packages file %s ...",
+                filename,
+            )
+            with open(
+                filename, encoding="UTF-8", errors="replace"
+            ) as file_obj:
+                for section in apt_pkg.TagFile(file_obj):
+                    yield (IndexType.PACKAGES, section)
+        for filename in self._get_files("Sources"):
+            _progress(
+                "processing sources file %s ...",
+                filename,
+            )
+            with open(
+                filename, encoding="UTF-8", errors="replace"
+            ) as file_obj:
+                for section in apt_pkg.TagFile(file_obj):
+                    yield (IndexType.SOURCES, section)
