@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Defaults for Germinate."""
 
 # Copyright (c) 2011 Canonical Ltd.
@@ -14,18 +13,17 @@
 # General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Germinate; see the file COPYING.  If not, write to the Free
-# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301, USA.
+# along with Germinate; see the file COPYING.  If not, see
+# <https://www.gnu.org/licenses/>.
 
 # Where do we get up-to-date seeds from?
-seeds = 'http://people.canonical.com/~ubuntu-archive/seeds/'
-seeds_bzr = 'http://bazaar.launchpad.net/~ubuntu-core-dev/ubuntu-seeds/'
-seeds_git = 'git://git.launchpad.net/~ubuntu-core-dev/ubuntu-seeds/+git/'
-release = 'ubuntu.bionic'
+seeds = "https://ubuntu-archive-team.ubuntu.com/seeds/"
+seeds_bzr = "http://bazaar.launchpad.net/~ubuntu-core-dev/ubuntu-seeds/"
+seeds_git = "git://git.launchpad.net/~ubuntu-core-dev/ubuntu-seeds/+git/"
+release = "ubuntu.questing"
 
 # If we need to download Packages.gz and/or Sources.gz, where do we get
 # them from?
-mirror = 'http://archive.ubuntu.com/ubuntu/'
-dist = 'bionic'
-arch = 'i386'
+mirror = "http://archive.ubuntu.com/ubuntu/"
+dist = "questing"
+arch = "amd64"
