@@ -13,9 +13,8 @@
 # General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Germinate; see the file COPYING.  If not, write to the Free
-# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301, USA.
+# along with Germinate; see the file COPYING.  If not, see
+# <https://www.gnu.org/licenses/>.
 
 import atexit
 import io
@@ -148,7 +147,7 @@ class Seed:
             path = os.path.join(base, repository)
             if not path.endswith("/"):
                 path += "/"
-            command = ["git", "clone"]
+            command = ["git", "clone", "--depth", "1"]
             if git_branch is not None:
                 command.extend(["-b", git_branch])
                 _logger.info("Cloning branch %s of %s", git_branch, path)
