@@ -11,11 +11,8 @@
 # General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Germinate; see the file COPYING.  If not, write to the Free
-# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301, USA.
-
-from __future__ import print_function
+# along with Germinate; see the file COPYING.  If not, see
+# <https://www.gnu.org/licenses/>.
 
 try:
     import importlib.metadata as importlib_metadata
